@@ -20,11 +20,14 @@ class GSHLSPlayer:
         if cap.isOpened() == False:
             self._logger.error("unable to open playlist")
             return
-
+        fps = cap.get(cv2.CAP_PROP_FPS)
+        wait_ms = int(1000 / fps)
+        self._logger.info(f"playing back HLS-Playlist with {fps} fps")
         while True:
             ret, frame = cap.read()
             if not ret:
                 break
+            time.sleep(wait_ms)
             onframe(self.gsdbs, "hls_playlist", frame)
         cap.release()
-        cv2.destroyAllWindows()
\ No newline at end of file
+        cv2.destroyAllWindows()
